"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DiagramLegendGenerator = void 0;
var diagram_legend_1 = require("./diagram_legend");
/**
 * Class for generating diagram legends.
 */
var DiagramLegendGenerator = /** @class */ (function () {
    function DiagramLegendGenerator() {
    }
    /**
     * Creates a legend for the given PlantUML code.
     * @param plantUml The PlantUML lines of code for which the legend is generated.
     * @returns The legend for the PlantUML code.
     */
    DiagramLegendGenerator.createForPlantUmlLines = function (plantUml) {
        // Check for a trailing "{" too to distinguish between a dummy type and a real class
        var hasClassItem = plantUml.some(function (str) { return str.startsWith("class ") && str.endsWith("{"); });
        var hasAbstractClassItem = plantUml.some(function (str) { return str.startsWith("abstract "); });
        var hasInterfaceItem = plantUml.some(function (str) { return str.startsWith("interface "); });
        var hasPublicPropertyItem = plantUml.some(function (str) { return / \+\w+ : /.test(str); });
        var hasProtectedPropertyItem = plantUml.some(function (str) { return / \#\w+ : /.test(str); });
        var hasPrivatePropertyItem = plantUml.some(function (str) { return / \-\w+ : /.test(str); });
        var hasPublicMethodItem = plantUml.some(function (str) { return / \+\w+\(/.test(str); });
        var hasProtectedMethodItem = plantUml.some(function (str) { return / \#\w+\(/.test(str); });
        var hasPrivateMethodItem = plantUml.some(function (str) { return / \-\w+\(/.test(str); });
        var hasStaticMemberItem = plantUml.some(function (str) { return str.indexOf("{static}") !== -1; });
        var hasAbstractMemberItem = plantUml.some(function (str) { return str.indexOf("{abstract}") !== -1; });
        return new diagram_legend_1.DiagramLegend(hasClassItem, hasAbstractClassItem, hasInterfaceItem, hasPublicPropertyItem, hasProtectedPropertyItem, hasPrivatePropertyItem, hasPublicMethodItem, hasProtectedMethodItem, hasPrivateMethodItem, hasStaticMemberItem, hasAbstractMemberItem);
    };
    return DiagramLegendGenerator;
}());
exports.DiagramLegendGenerator = DiagramLegendGenerator;
